==> haskell-crypto-numbers-0.2.7-191-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-numbers
version:              0.2.7
visibility:           public
id:                   crypto-numbers-0.2.7-DDcnZ6d52CxGsq66NlQaTq
key:                  crypto-numbers-0.2.7-DDcnZ6d52CxGsq66NlQaTq
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-crypto-numbers
synopsis:             Cryptographic numbers: functions and algorithms
description:          Cryptographic numbers: functions and algorithms
category:             Cryptography
abi:                  b7ade58bc0b9b5a1b7dc26a27a4eba40
exposed:              True
exposed-modules:
    Crypto.Number.Basic Crypto.Number.F2m Crypto.Number.Generate
    Crypto.Number.ModArithmetic Crypto.Number.Polynomial
    Crypto.Number.Prime Crypto.Number.Serialize

import-dirs:          /usr/lib/ghc-8.10.4/site-local/crypto-numbers-0.2.7
library-dirs:         /usr/lib/ghc-8.10.4/site-local/crypto-numbers-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/crypto-numbers-0.2.7
hs-libraries:         HScrypto-numbers-0.2.7-DDcnZ6d52CxGsq66NlQaTq
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    crypto-random-0.0.9-GOCd3WXL8afCEQNCOJ75uX ghc-prim-0.6.1
    integer-gmp-1.0.3.0 vector-0.12.2.0-Ah3gN1EocbtK6SkxatFMVl

haddock-interfaces:
    /usr/share/doc/haskell-crypto-numbers/html/crypto-numbers.haddock

haddock-html:         /usr/share/doc/haskell-crypto-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-numbers-0.2.7-197-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-numbers
version:              0.2.7
visibility:           public
id:                   crypto-numbers-0.2.7-Jevz0Vt5IRT8deBlxuiWgB
key:                  crypto-numbers-0.2.7-Jevz0Vt5IRT8deBlxuiWgB
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-crypto-numbers
synopsis:             Cryptographic numbers: functions and algorithms
description:          Cryptographic numbers: functions and algorithms
category:             Cryptography
abi:                  72d9ff27d0b7360582cc25c3c4db4185
exposed:              True
exposed-modules:
    Crypto.Number.Basic Crypto.Number.F2m Crypto.Number.Generate
    Crypto.Number.ModArithmetic Crypto.Number.Polynomial
    Crypto.Number.Prime Crypto.Number.Serialize

import-dirs:          /usr/lib/ghc-8.10.4/site-local/crypto-numbers-0.2.7
library-dirs:         /usr/lib/ghc-8.10.4/site-local/crypto-numbers-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/crypto-numbers-0.2.7
hs-libraries:         HScrypto-numbers-0.2.7-Jevz0Vt5IRT8deBlxuiWgB
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    crypto-random-0.0.9-B2yQTa3VHmAHgWBcjR4cVx ghc-prim-0.6.1
    integer-gmp-1.0.3.0 vector-0.12.2.0-H4M3IeJ8Uw8LGLOdKfxtZO

haddock-interfaces:
    /usr/share/doc/haskell-crypto-numbers/html/crypto-numbers.haddock

haddock-html:         /usr/share/doc/haskell-crypto-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
